[![Build Status](https://travis-ci.com/louisleroy5/translater.svg?token=qpRnYhTVUeLJ5WM1w9Wx&branch=master)](https://travis-ci.com/louisleroy5/translater)
[![Coverage Status](https://coveralls.io/repos/github/louisleroy5/translater/badge.svg?branch=develop&t=PLPFwA)](https://coveralls.io/github/louisleroy5/translater?branch=develop)
[![Documentation Status](https://readthedocs.org/projects/translater/badge/?version=latest)](https://translater.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# Translater

**python for converting building simulation archetypes**

Convert IDF file (EnergyPlus) to BUI file (TRNBuild)

## Overview

** Translater** is a Python package that helps converting building archetypes. The public feature released in this
version is the  conversion of [EnergyPlus](https://energyplus.net) IDF models to Trnsys [TrnBuild](http://www.trnsys.com/features/suite-of-tools.php.html) Models (compatible with the multizone building model). For a list of features
currently in development see the [In development](#in-development) section.

## Authors

This work is developed by a small team of building energy simulation enthusiasts

- Louis Leroy, Master Student at Polytechnique Montréal (Corresponding Author)
- Samuel Letellier-Duchesne, PhD Candidate at Polytechnique Montréal

